@@ -3,6 +3,6 @@
 __all__ = [
     'ruphrase',
 ]
-__version__ = '0.0.2'
+__version__ = '0.0.3'
 
-from ngutils.functions import *
\ No newline at end of file
+from ruphrase.functions import *
